"""Representation of quantities with SI units.

`si_units` provides the `SIObject` class that represents physical quantities
as values with units. Values can be any Python data types that are suitable
for arithmetic operations, such as `float`, `numpy.ndarray` or `torch.tensor`.
Usually, a `SIObject` is created by multiplying a value by a `SIObject` that
represents a unit.

Examples:
    Calculate the ideal gas pressure and convert to bar.

    >>> from si_units import CELSIUS, METER, MOL, RGAS, BAR
    >>> temperature = 25.0 * CELSIUS
    >>> volume = 1.5 * METER**3
    >>> moles = 75.0 * MOL
    >>> pressure = moles * RGAS * temperature / volume
    >>> print(f"The pressure is {pressure / BAR:.2f} bar")
    The pressure is 1.24 bar
"""
# from si_units._core import SIObject
from si_units._core import (
    SIObject,
    Angle,
    array,
    linspace,
    logspace,
    SECOND,
    METER,
    KILOGRAM,
    AMPERE,
    KELVIN,
    CELSIUS,
    DEBYE,
    DEGREES,
    RADIANS,
    DAY,
    MOL,
    CANDELA,
    DVCS,
    CLIGHT,
    PLANCK,
    QE,
    KB,
    NAV,
    KCD,
    HERTZ,
    NEWTON,
    PASCAL,
    JOULE,
    WATT,
    COULOMB,
    VOLT,
    FARAD,
    OHM,
    SIEMENS,
    WEBER,
    TESLA,
    HENRY,
    ANGSTROM,
    AMU,
    AU,
    BAR,
    CALORIE,
    GRAM,
    HOUR,
    LITER,
    MINUTE,
    G,
    RGAS,
    QUECTO,
    RONTO,
    YOCTO,
    ZEPTO,
    ATTO,
    FEMTO,
    PICO,
    NANO,
    MICRO,
    MILLI,
    CENTI,
    DECI,
    DECA,
    HECTO,
    KILO,
    MEGA,
    GIGA,
    TERA,
    PETA,
    EXA,
    ZETTA,
    YOTTA,
    RONNA,
    QUETTA,
    __version__,
)

__all__ = [
    "SIObject",
    "Angle",
    "array",
    "linspace",
    "logspace",
    "SECOND",
    "METER",
    "KILOGRAM",
    "AMPERE",
    "KELVIN",
    "CELSIUS",
    "DEBYE",
    "DEGREES",
    "RADIANS",
    "DAY",
    "MOL",
    "CANDELA",
    "DVCS",
    "CLIGHT",
    "PLANCK",
    "QE",
    "KB",
    "NAV",
    "KCD",
    "HERTZ",
    "NEWTON",
    "PASCAL",
    "JOULE",
    "WATT",
    "COULOMB",
    "VOLT",
    "FARAD",
    "OHM",
    "SIEMENS",
    "WEBER",
    "TESLA",
    "HENRY",
    "ANGSTROM",
    "AMU",
    "AU",
    "BAR",
    "CALORIE",
    "GRAM",
    "HOUR",
    "LITER",
    "MINUTE",
    "G",
    "RGAS",
    "QUECTO",
    "RONTO",
    "YOCTO",
    "ZEPTO",
    "ATTO",
    "FEMTO",
    "PICO",
    "NANO",
    "MICRO",
    "MILLI",
    "CENTI",
    "DECI",
    "DECA",
    "HECTO",
    "KILO",
    "MEGA",
    "GIGA",
    "TERA",
    "PETA",
    "EXA",
    "ZETTA",
    "YOTTA",
    "RONNA",
    "QUETTA",
    "__version__",
]
